#!/bin/sh

. /tmp/openit-cfg-shenv

# Author : Romnick C. Coros
# Last Update : January 5, 2017

#Declare variables for the current httpd.conf and the backup
OLD_HTTPD=$CONFIG_DIR/httpd/httpd.conf.pre_2002-1
HTTPD=$CONFIG_DIR/httpd/httpd.conf
USESSL=$CONFIG_DIR/httpd/use_ssl

#Backup the old httpd.conf
if [ ! -f $OLD_HTTPD ];	then
	cp $HTTPD $OLD_HTTPD
fi




#Get values from the old httpd.conf
port=`grep Listen $OLD_HTTPD | grep -v 127.0.0.1 | cut -d" " -f2 | cut -d "." -f 4 | head -1`
servername=`grep ServerName $OLD_HTTPD | cut -d " " -f2`
backendport=`grep "127.0.0.1:" $OLD_HTTPD | cut -d ":" -f2`
virtualhost=`grep "VirtualHost _default_:" $OLD_HTTPD | cut -d ":" -f2 | cut -d ">" -f1`
user=`grep "User " $OLD_HTTPD | cut -d " " -f2`
group=`grep "Group " $OLD_HTTPD | cut -d " " -f2`

#Get default values if not existing on old httpd.conf
if [ -z "$backendport" ]; then
	backendport=8880
fi
if [ -z "$servername" ]; then
	servername=`hostname`
fi

#Check if we're using SSL
#If yes use an ssl version of the httpd.conf
if [ ! -f $USESSL ]; then
	#Copy the new httpd.conf to installation
	cp files/httpd.conf $HTTPD

	#Replace the port value for http protocol
	sed -i -e 's/Listen 8080/Listen '$port'/g' $HTTPD
else
	#Copy the new httpd.conf to installation
	cp files/httpd-ssl.conf $HTTPD
	
	#Replace the port value for https protocol
	sed -i -e 's/Listen 443/Listen '$port'/g' $HTTPD
fi

#Replace the values in the new httpd using the values from the old one
sed -i -e 's/User openit/User '$user'/g' $HTTPD
sed -i -e 's/Group openit/Group '$group'/g' $HTTPD
sed -i -e 's/Listen 127.0.0.1:8880/Listen 127.0.0.1:'$backendport'/g' $HTTPD
sed -i -e 's/ServerName localhost/ServerName '$servername'/g' $HTTPD
sed -i -e 's/<VirtualHost _default_:443>/<VirtualHost _default_:'$virtualhost'>/g' $HTTPD

#Make sure TEMP_DIR/httpd is owned by the user
chown -R $user:$group $TEMP_DIR/httpd

#Replace CGIBIN_DIR 
bindir=$(echo $BIN_DIR | sed 's_/_\\/_g')
sed -i -e 's/${CGIBIN_DIR}/'$bindir'/g' $HTTPD

#Remove phpinfo.php and test.php if existing
if [ -e $ROOT_DIR/html/phpinfo.php ]; then
	rm -rf $ROOT_DIR/html/phpinfo.php
fi

if [ -e $ROOT_DIR/html/test.php ]; then
	rm -rf $ROOT_DIR/html/test.php
fi